PYHPEIMC Python project
=======================

A sample project that exists as an aid for HPE IMC customers to access the RESTFUL API (eAPI) of the Network Management
System Natively from within python.

For example usages, please see the

This project is offered under and Apache2 license and is not supported officialy by HPE.

For more information, please visit the project home page at `GITHub.com <https://github.com/HPENetworking/PYHPEIMC>`_.


What's Changed:

Fixed Readme File
Fixed setup.py to remove unnecessary data directory